/**
 * When called at the right times, this speeds up your test suite by removing `<script>` tags that Angular component tests leave in the DOM. By default Angular dynamically adds `<script>` tags into the `<head>` of the document corresponding to component styles. In Jasmine tests they are never cleaned up. This can cause hundreds or even thousands of style tags to accumulate, making component tests slow down as your test suite runs. In Chrome debugger's performance tab, this time will show up under the activity "Recalculate Style".
 *
 * The first time this function is called it memorizes the `<script>` tags in the DOM, then each time it is called after it removes any that appeared since. A simple way to use this effectively is to call it in a `beforeEach()`.
 *
 * ```ts
 * beforeEach(() => {
 *   trimLeftoverStyles();
 * });
 * ```
 */
export declare function trimLeftoverStyles(): void;
/** @hidden */
export declare function resetTrimLeftoverStyles(): void;
